@@ -73,7 +73,8 @@ extern volatile int global_interrupt;
 struct snapraid_option {
 	int gui; /**< Gui output. */
 	int auditonly; /**< In check, checks only the hash and not the parity. */
-	int badonly; /**< In fix, fixes only the blocks marked as bad. */
+	int badfileonly; /**< In fix, fixes only files marked as bad. */
+	int badblockonly; /**< In fix, fixes only the blocks marked as bad. */
 	int syncedonly; /**< In fix, fixes only files that are synced. */
 	int prehash; /**< Enables the prehash mode for sync. */
 	unsigned io_error_limit; /**< Max number of input/output errors before aborting. */
