@@ -407,7 +407,7 @@ int smartctl_flush(FILE* f, const char* file, const char* name);
 /****************************************************************************/
 /* thread */
 
-#if HAVE_PTHREAD
+#if HAVE_THREAD
 /**
  * Control when to signal the condition variables.
  *
@@ -420,19 +420,19 @@ extern int thread_cond_signal_outside;
 /**
  * Thread wrappers to handle error conditions.
  */
-void thread_mutex_init(pthread_mutex_t* mutex, pthread_mutexattr_t* attr);
-void thread_mutex_destroy(pthread_mutex_t* mutex);
-void thread_mutex_lock(pthread_mutex_t* mutex);
-void thread_mutex_unlock(pthread_mutex_t* mutex);
-void thread_cond_init(pthread_cond_t* cond, pthread_condattr_t* attr);
-void thread_cond_destroy(pthread_cond_t* cond);
-void thread_cond_signal(pthread_cond_t* cond);
-void thread_cond_broadcast(pthread_cond_t* cond);
-void thread_cond_wait(pthread_cond_t* cond, pthread_mutex_t* mutex);
-void thread_cond_signal_and_unlock(pthread_cond_t* cond, pthread_mutex_t* mutex);
-void thread_cond_broadcast_and_unlock(pthread_cond_t* cond, pthread_mutex_t* mutex);
-void thread_create(pthread_t* thread, pthread_attr_t* attr, void *(* func)(void *), void *arg);
-void thread_join(pthread_t thread, void** retval);
+void thread_mutex_init(thread_mutex_t* mutex);
+void thread_mutex_destroy(thread_mutex_t* mutex);
+void thread_mutex_lock(thread_mutex_t* mutex);
+void thread_mutex_unlock(thread_mutex_t* mutex);
+void thread_cond_init(thread_cond_t* cond);
+void thread_cond_destroy(thread_cond_t* cond);
+void thread_cond_signal(thread_cond_t* cond);
+void thread_cond_broadcast(thread_cond_t* cond);
+void thread_cond_wait(thread_cond_t* cond, thread_mutex_t* mutex);
+void thread_cond_signal_and_unlock(thread_cond_t* cond, thread_mutex_t* mutex);
+void thread_cond_broadcast_and_unlock(thread_cond_t* cond, thread_mutex_t* mutex);
+void thread_create(thread_id_t* thread, void* (* func)(void *), void *arg);
+void thread_join(thread_id_t thread, void** retval);
 #endif
 
 #endif
